@@ -21,10 +21,13 @@ class Requirement(object):
         self.override = override
         self.private = private
         self.build_require = False
+        self.build_require_context = None
+        self.force_host_context = False
         self._locked_id = None
 
     def lock(self, locked_ref, locked_id):
-        # When a requirment is locked it doesn't has ranges
+        assert locked_ref is not None
+        # When a requirement is locked it doesn't has ranges
         self.ref = self.range_ref = locked_ref
         self._locked_id = locked_id  # And knows the ID of the locked node that is pointing to
 
@@ -41,6 +44,13 @@ class Requirement(object):
         if version.startswith("[") and version.endswith("]"):
             return version[1:-1]
 
+    @property
+    def alias(self):
+        version = self.ref.version
+        if version.startswith("(") and version.endswith(")"):
+            return ConanFileReference(self.ref.name, version[1:-1], self.ref.user, self.ref.channel,
+                                      self.ref.revision, validate=False)
+
     @property
     def is_resolved(self):
         """ returns True if the version_range reference has been already resolved to a
@@ -112,6 +122,14 @@ class Requirements(OrderedDict):
         else:
             self[name] = new_requirement
 
+    def override(self, ref):
+        name = ref.name
+        old_requirement = self.get(ref.name)
+        if old_requirement is not None:
+            self[name] = Requirement(ref, private=False, override=False)
+        else:
+            self[name] = Requirement(ref, private=False, override=True)
+
     def update(self, down_reqs, output, own_ref, down_ref):
         """ Compute actual requirement values when downstream values are defined
         param down_reqs: the current requirements as coming from downstream to override
