@@ -1,13 +1,14 @@
 import json
 import os
-import random
 import shlex
 import shutil
+import socket
 import sys
 import textwrap
 import threading
 import time
 import uuid
+import zipfile
 from collections import OrderedDict
 from contextlib import contextmanager
 
@@ -20,7 +21,6 @@ from webtest.app import TestApp
 
 from conans import load
 from conans.cli.cli import Cli
-from conans.cli.output import ConanOutput
 from conans.client.api.conan_api import ConanAPIV2
 from conans.client.cache.cache import ClientCache
 from conans.client.cache.remote_registry import Remotes
@@ -30,14 +30,16 @@ from conans.client.rest.file_uploader import IterableToFileAdapter
 from conans.client.runner import ConanRunner
 from conans.client.tools import environment_append
 from conans.client.tools.files import replace_in_file
-from conans.errors import NotFoundException, RecipeNotFoundException, PackageNotFoundException
+from conans.errors import NotFoundException
 from conans.model.manifest import FileTreeManifest
 from conans.model.profile import Profile
 from conans.model.ref import ConanFileReference, PackageReference
 from conans.model.settings import Settings
-from conans.server.revision_list import _RevisionEntry
-from conans.test.utils.genconanfile import GenConanfile
-from conans.test.utils.mocks import MockedUserIO, TestBufferConanOutput
+from conans.test.assets import copy_assets
+from conans.test.assets.genconanfile import GenConanfile
+from conans.test.utils.artifactory import ARTIFACTORY_DEFAULT_USER, ARTIFACTORY_DEFAULT_PASSWORD, \
+    ArtifactoryServer
+from conans.test.utils.mocks import MockedUserIO, TestBufferConanOutput, RedirectedTestOutput
 from conans.test.utils.scm import create_local_git_repo, create_local_svn_checkout, \
     create_remote_svn_repo
 from conans.test.utils.server_launcher import (TESTING_REMOTE_PRIVATE_PASS,
@@ -50,10 +52,6 @@ from conans.util.files import mkdir, save_files
 
 NO_SETTINGS_PACKAGE_ID = "5ab84d6acfe1f23c4fae0ab88f26e3a396351ac9"
 
-ARTIFACTORY_DEFAULT_USER = os.getenv("ARTIFACTORY_DEFAULT_USER", "admin")
-ARTIFACTORY_DEFAULT_PASSWORD = os.getenv("ARTIFACTORY_DEFAULT_PASSWORD", "password")
-ARTIFACTORY_DEFAULT_URL = os.getenv("ARTIFACTORY_DEFAULT_URL", "http://localhost:8090/artifactory")
-
 
 def inc_recipe_manifest_timestamp(cache, reference, inc_time):
     ref = ConanFileReference.loads(reference)
@@ -71,7 +69,7 @@ def inc_package_manifest_timestamp(cache, package_reference, inc_time):
     manifest.save(path)
 
 
-def test_profile(profile=None, settings=None):
+def create_profile(profile=None, settings=None):
     if profile is None:
         profile = Profile()
     if profile.processed_settings is None:
@@ -238,138 +236,6 @@ class TestRequester(object):
             kwargs["headers"].update(mock_request.headers)
 
 
-class ArtifactoryServerStore(object):
-
-    def __init__(self, repo_url, user, password):
-        self._user = user or ARTIFACTORY_DEFAULT_USER
-        self._password = password or ARTIFACTORY_DEFAULT_PASSWORD
-        self._repo_url = repo_url
-
-    @property
-    def _auth(self):
-        return self._user, self._password
-
-    @staticmethod
-    def _root_recipe(ref):
-        return "{}/{}/{}/{}".format(ref.user, ref.name, ref.version, ref.channel)
-
-    @staticmethod
-    def _ref_index(ref):
-        return "{}/index.json".format(ArtifactoryServerStore._root_recipe(ref))
-
-    @staticmethod
-    def _pref_index(pref):
-        tmp = ArtifactoryServerStore._root_recipe(pref.ref)
-        return "{}/{}/package/{}/index.json".format(tmp, pref.ref.revision, pref.id)
-
-    def get_recipe_revisions(self, ref):
-        time.sleep(0.1)  # Index appears to not being updated immediately after a remove
-        url = "{}/{}".format(self._repo_url, self._ref_index(ref))
-        response = requests.get(url, auth=self._auth)
-        response.raise_for_status()
-        the_json = response.json()
-        if not the_json["revisions"]:
-            raise RecipeNotFoundException(ref)
-        tmp = [_RevisionEntry(i["revision"], i["time"]) for i in the_json["revisions"]]
-        return tmp
-
-    def get_package_revisions(self, pref):
-        time.sleep(0.1)  # Index appears to not being updated immediately
-        url = "{}/{}".format(self._repo_url, self._pref_index(pref))
-        response = requests.get(url, auth=self._auth)
-        response.raise_for_status()
-        the_json = response.json()
-        if not the_json["revisions"]:
-            raise PackageNotFoundException(pref)
-        tmp = [_RevisionEntry(i["revision"], i["time"]) for i in the_json["revisions"]]
-        return tmp
-
-    def get_last_revision(self, ref):
-        revisions = self.get_recipe_revisions(ref)
-        return revisions[0]
-
-    def get_last_package_revision(self, ref):
-        revisions = self.get_package_revisions(ref)
-        return revisions[0]
-
-    def package_exists(self, pref):
-        try:
-            if pref.revision:
-                path = self.server_store.package(pref)
-            else:
-                path = self.test_server.server_store.package_revisions_root(pref)
-            return self.test_server.server_store.path_exists(path)
-        except NotFoundException:  # When resolves the latest and there is no package
-            return False
-
-
-class ArtifactoryServer(object):
-
-    def __init__(self, *args, **kwargs):
-        self._user = ARTIFACTORY_DEFAULT_USER
-        self._password = ARTIFACTORY_DEFAULT_PASSWORD
-        self._url = ARTIFACTORY_DEFAULT_URL
-        self._repo_name = "conan_{}".format(str(uuid.uuid4()).replace("-", ""))
-        self.create_repository()
-        self.server_store = ArtifactoryServerStore(self.repo_url, self._user, self._password)
-
-    @property
-    def _auth(self):
-        return self._user, self._password
-
-    @property
-    def repo_url(self):
-        return "{}/{}".format(self._url, self._repo_name)
-
-    @property
-    def repo_api_url(self):
-        return "{}/api/conan/{}".format(self._url, self._repo_name)
-
-    def recipe_revision_time(self, ref):
-        revs = self.server_store.get_recipe_revisions(ref)
-        for r in revs:
-            if r.revision == ref.revision:
-                return r.time
-        return None
-
-    def package_revision_time(self, pref):
-        revs = self.server_store.get_package_revisions(pref)
-        for r in revs:
-            if r.revision == pref.revision:
-                return r.time
-        return None
-
-    def create_repository(self):
-        url = "{}/api/repositories/{}".format(self._url, self._repo_name)
-        config = {"key": self._repo_name, "rclass": "local", "packageType": "conan"}
-        ret = requests.put(url, auth=self._auth, json=config)
-        ret.raise_for_status()
-
-    def package_exists(self, pref):
-        try:
-            revisions = self.server_store.get_package_revisions(pref)
-            if pref.revision:
-                for r in revisions:
-                    if pref.revision == r.revision:
-                        return True
-                return False
-            return True
-        except Exception:  # When resolves the latest and there is no package
-            return False
-
-    def recipe_exists(self, ref):
-        try:
-            revisions = self.server_store.get_recipe_revisions(ref)
-            if ref.revision:
-                for r in revisions:
-                    if ref.revision == r.revision:
-                        return True
-                return False
-            return True
-        except Exception:  # When resolves the latest and there is no package
-            return False
-
-
 class TestServer(object):
     def __init__(self, read_permissions=None,
                  write_permissions=None, users=None, plugins=None, base_path=None,
@@ -458,8 +324,8 @@ if get_env("CONAN_TEST_WITH_ARTIFACTORY", False):
 
 def _copy_cache_folder(target_folder):
     # Some variables affect to cache population (take a different default folder)
-    vars = [CONAN_V2_MODE_ENVVAR, 'CC', 'CXX', 'PATH']
-    cache_key = hash('|'.join(map(str, [os.environ.get(it, None) for it in vars])))
+    vars_ = [CONAN_V2_MODE_ENVVAR, 'CC', 'CXX', 'PATH']
+    cache_key = hash('|'.join(map(str, [os.environ.get(it, None) for it in vars_])))
     master_folder = _copy_cache_folder.master.setdefault(cache_key, temp_folder(create_dir=False))
     if not os.path.exists(master_folder):
         # Create and populate the cache folder with the defaults
@@ -478,7 +344,7 @@ _copy_cache_folder.master = dict()  # temp_folder(create_dir=False)
 def redirect_output(target):
     original_stdout = sys.stdout
     original_stderr = sys.stderr
-    #TODO: change in 2.0
+    # TODO: change in 2.0
     # redirecting both of them to the same target for the moment
     # to assign to Testclient out
     sys.stdout = target
@@ -551,6 +417,8 @@ class TestClient(object):
         mkdir(self.current_folder)
         self.tune_conan_conf(cache_folder, cpu_count, revisions_enabled)
 
+        self.out = RedirectedTestOutput()
+
     def load(self, filename):
         return load(os.path.join(self.current_folder, filename))
 
@@ -611,7 +479,7 @@ class TestClient(object):
         if cpu_count:
             replace_in_file(cache.conan_conf_path,
                             "# cpu_count = 1", "cpu_count = %s" % cpu_count,
-                            output=TestBufferConanOutput(), strict=not bool(cache_folder))
+                            output=Mock(), strict=not bool(cache_folder))
 
         if revisions_enabled is not None:
             self._set_revisions(revisions_enabled)
@@ -652,24 +520,20 @@ class TestClient(object):
                            http_requester=self._http_requester, runner=self.runner)
         return conan
 
-    def get_conan_api_v1(self, user_io=None):
-        if user_io:
-            self.out = user_io.out
-        else:
-            self.out = TestBufferConanOutput()
-        user_io = user_io or MockedUserIO(self.users, out=self.out)
-        conan = Conan(cache_folder=self.cache_folder, output=self.out, user_io=user_io,
+    def get_conan_api_v1(self):
+        user_io = MockedUserIO(self.users)
+        conan = Conan(cache_folder=self.cache_folder, user_io=user_io,
                       http_requester=self._http_requester, runner=self.runner)
         return conan
 
-    def get_conan_api(self, user_io=None):
+    def get_conan_api(self):
         if os.getenv("CONAN_V2_CLI"):
             return self.get_conan_api_v2()
         else:
-            return self.get_conan_api_v1(user_io)
+            return self.get_conan_api_v1()
 
-    def run_cli(self, command_line, user_io=None, assert_error=False):
-        conan = self.get_conan_api(user_io)
+    def run_cli(self, command_line, assert_error=False):
+        conan = self.get_conan_api()
         self.api = conan
         if os.getenv("CONAN_V2_CLI"):
             command = Cli(conan)
@@ -693,20 +557,15 @@ class TestClient(object):
         self._handle_cli_result(command_line, assert_error=assert_error, error=error)
         return error
 
-    def run(self, command_line, user_io=None, assert_error=False):
+    def run(self, command_line, assert_error=False):
         """ run a single command as in the command line.
             If user or password is filled, user_io will be mocked to return this
             tuple if required
         """
-        # TODO: remove in 2.0
-        if os.getenv("CONAN_V2_CLI"):
-            from conans.test.utils.mocks import RedirectedTestOutput
-            self.out = RedirectedTestOutput()
-            with redirect_output(self.out):
-                error = self.run_cli(command_line, user_io=user_io, assert_error=assert_error)
-        else:
-            error = self.run_cli(command_line, user_io=user_io, assert_error=assert_error)
-
+        from conans.test.utils.mocks import RedirectedTestOutput
+        self.out = RedirectedTestOutput()  # Initialize each command
+        with redirect_output(self.out):
+            error = self.run_cli(command_line, assert_error=assert_error)
         return error
 
     def run_command(self, command, cwd=None, assert_error=False):
@@ -744,14 +603,8 @@ class TestClient(object):
         if not files:
             mkdir(self.current_folder)
 
-    def copy_from_assets(self, origin_folder, assets):
-        for asset in assets:
-            s = os.path.join(origin_folder, asset)
-            d = os.path.join(self.current_folder, asset)
-            if os.path.isdir(s):
-                shutil.copytree(s, d)
-            else:
-                shutil.copy2(s, d)
+    def copy_assets(self, origin_folder, assets=None):
+        copy_assets(origin_folder, self.current_folder, assets)
 
     # Higher level operations
     def remove_all(self):
@@ -882,6 +735,14 @@ class TurboTestClient(TestClient):
         return rev
 
 
+def get_free_port():
+    sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+    sock.bind(('localhost', 0))
+    ret = sock.getsockname()[1]
+    sock.close()
+    return ret
+
+
 class StoppableThreadBottle(threading.Thread):
     """
     Real server to test download endpoints
@@ -889,8 +750,8 @@ class StoppableThreadBottle(threading.Thread):
 
     def __init__(self, host=None, port=None):
         self.host = host or "127.0.0.1"
-        self.port = port or random.randrange(48000, 49151)
         self.server = bottle.Bottle()
+        self.port = port or get_free_port()
         super(StoppableThreadBottle, self).__init__(target=self.server.run,
                                                     kwargs={"host": self.host, "port": self.port})
         self.daemon = True
@@ -902,3 +763,14 @@ class StoppableThreadBottle(threading.Thread):
     def run_server(self):
         self.start()
         time.sleep(1)
+
+
+def zipdir(path, zipfilename):
+    with zipfile.ZipFile(zipfilename, 'w', zipfile.ZIP_DEFLATED) as z:
+        for root, _, files in os.walk(path):
+            for f in files:
+                file_path = os.path.join(root, f)
+                if file_path == zipfilename:
+                    continue
+                relpath = os.path.relpath(file_path, path)
+                z.write(file_path, relpath)
